@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '1.9.9.9';
+    return '2.0';
   }
 
   function GetHelp()
