@@ -33,6 +33,11 @@ if ($this->GetPreference('canonical_block_title','') != '') {
 } else {
     $canonical_block = '';
 }
+if ($this->GetPreference('key_smarty','') != '') {
+    $key_smarty = $this->GetPreference('key_smarty','');
+} else {
+    $key_smarty = '';
+}
 if ($this->GetPreference('html_title','en') != '') {
     $lang_block = $this->GetPreference('html_title','en');
 } else {
@@ -107,6 +112,16 @@ if ($keywords != '') {
         $skipwords[] = $skipword;
     }
 
+	if ($smarty->get_template_vars($key_smarty) != '') {
+		$keywordssmarty = $smarty->get_template_vars($key_smarty);
+		$keywordssmarty = str_replace(' ','',$keywordssmarty);
+		$keywordssmarty = explode(',',$keywordssmarty);
+	}
+
+    foreach ($keywordssmarty as $smartkey => $smartword ) { //Turn Smarty keywords into an array
+        $smartwords[] = $smartword;
+    }
+
     $keywordsdefault = $this->GetPreference('key_default',''); //Get the list of Default keywords to include
     $keywordsdefault = str_replace(' ','',$keywordsdefault);
     $keywordsdefault = explode(',',$keywordsdefault);
@@ -116,11 +131,16 @@ if ($keywords != '') {
     }
 }
 
-$keywordsskip = preg_split("/[\s,]+/", $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very'));
+$keywordsskip = preg_split("/[\s,]+/", $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very, every, been, with, then, this, will, don\'t'));
 
 if ($words != '') {
     $worddiff = array_diff($words, $skipwords); //Strip any STOP words out of the keywords
-    $worddiff = array_diff($worddiff, $defwords); //Strip any Default keywords out to prevent duplication
+	if ($smarty->get_template_vars($key_smarty) != '') {
+		$worddiff = array_diff($worddiff, $smartwords); //Strip any Smarty keywords out to prevent duplication
+	}
+	if ($this->GetPreference($key_smarty) != '') {
+		$worddiff = array_diff($worddiff, $defwords); //Strip any Default keywords out to prevent duplication
+	}
 }
 
 if (is_array($worddiff)) {
@@ -252,8 +272,10 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('descriptions_title', $this->GetPreference('descriptions_title',''));
    $this->smarty->assign('keywordson_title', $this->GetPreference('keywordson_title','1'));
    $this->smarty->assign('keywords_title', $skipwords);
+   $this->smarty->assign('blobber', $blobber);
    $this->smarty->assign('keywords_default', $this->GetPreference('key_default',''));
-   $this->smarty->assign('keyskip_title', $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very'));
+   $this->smarty->assign('keywords_smarty', $smarty->get_template_vars($key_smarty));
+   $this->smarty->assign('keyskip_title', $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very, every, been, with, then, this, will, don\'t'));
    $this->smarty->assign('standard_title', $this->GetPreference('standard_title','1'));
    $this->smarty->assign('dublin_title', $this->GetPreference('dublin_title','0'));
    $this->smarty->assign('opengraph_title', $this->GetPreference('opengraph_title','0'));
