@@ -13,6 +13,9 @@ $this->SetPreference('stylesheet_name', $params['stylesheet_name']);
 $this->SetPreference('stylesheet_nocombine',
 		     (isset($params['stylesheet_nocombine'])?'1':'0'));
 
+$this->SetPreference('stylesheet_nolinks',
+		     (isset($params['stylesheet_nolinks'])?'1':'0'));
+
 $this->SetPreference('stylesheet_https',
 		     (isset($params['stylesheet_https'])?'1':'0'));
 
