@@ -182,6 +182,7 @@ $lang['key_length_help'] = 'Minimum character length before becoming a keyword';
 $lang['key_density'] = 'Density of keywords';
 $lang['key_density_help'] = 'How many times a word has to appear before becoming a Keyword';
 $lang['key_default'] = 'Set of default keywords to always include, comma seperated list';
+$lang['key_smarty'] = 'Keyword smarty tag';
 $lang['keyskip_title'] = 'Keyword STOP words';
 $lang['key_stop_help'] = 'Words not to include as keywords, comma seperated list';
 $lang['xml_title'] = 'Create an XML Google Sitemap';
@@ -260,7 +261,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.9.9.6 18 February 2014. Minor bug fix for https urls.</li>
 <li>Version 1.9.9.7 13 May 2014. Added additional Twitter meta tags plus minor cleaning up.</li>
 <li>Version 1.9.9.8 17 June 2014. Added addition default keyword skip words and made county and country fields accept more than 5 chars.</li>
-<li>Version 1.9.9.8 17 July 2014. Amend to GA Universal tracking code.</li>
+<li>Version 1.9.9.9 17 July 2014. Amend to GA Universal tracking code.</li>
+<li>Version 2.0 12 August 2014. Added the ability to specify keywords content block to append keywords per page. Minor bug fixes.</li>
 </ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
